@@ -10,8 +10,7 @@ from FunctionEncoder.Callbacks.BaseCallback import BaseCallback
 class DistanceCallback(BaseCallback):
 
     def __init__(self,
-                 testing_dataset:BaseDataset,
-                 device:Union[str, torch.device],
+                 dataloader:torch.utils.data.DataLoader,
                  logdir: Union[str, None] = None,
                  tensorboard: Union[None, SummaryWriter] = None,
                  prefix="test",
@@ -20,27 +19,36 @@ class DistanceCallback(BaseCallback):
         assert logdir is not None or tensorboard is not None, "Either logdir or tensorboard must be provided"
         assert logdir is None or tensorboard is None, "Only one of logdir or tensorboard can be provided"
         super(DistanceCallback, self).__init__()
-        self.testing_dataset = testing_dataset
-        self.device = device
+        self.dataloader = dataloader
         if logdir is not None:
             self.tensorboard = SummaryWriter(logdir)
         else:
             self.tensorboard = tensorboard
         self.prefix = prefix
         self.total_epochs = 0
+        self.data_iter = iter(self.dataloader)
+
+    def on_training_start(self, locals: dict) -> None:
+        if self.total_epochs == 0: # logs loss before any updates.
+            self.on_step(locals)
 
     def on_step(self, locals:dict):
         with torch.no_grad():
             function_encoder = locals["self"]
 
             # sample testing data
-            example_xs, example_ys, xs, ys, info = self.testing_dataset.sample()
+            try:
+                example_xs, example_ys, query_xs, query_ys, info = next(self.data_iter)
+            except StopIteration:
+                self.data_iter = iter(self.dataloader)
+                example_xs, example_ys, query_xs, query_ys, info = next(self.data_iter)
+
 
             # compute representation
-            y_hats = function_encoder.predict_from_examples(example_xs, example_ys, xs, method="least_squares")
+            y_hats = function_encoder.predict_from_examples(example_xs, example_ys, query_xs)
 
             # measure mse
-            loss = function_encoder._distance(y_hats, ys, squared=True).mean()
+            loss = function_encoder._distance(y_hats, query_ys, squared=True).mean()
 
             # log results
             self.tensorboard.add_scalar(f"{self.prefix}/mean_distance_squared", loss, self.total_epochs)
