@@ -7,6 +7,7 @@ from FunctionEncoder.Dataset.GaussianDonutDataset import GaussianDonutDataset
 from FunctionEncoder.Dataset.GaussianDataset import GaussianDataset
 from FunctionEncoder.Dataset.EuclideanDataset import EuclideanDataset
 from FunctionEncoder.Dataset.CategoricalDataset import CategoricalDataset
+from FunctionEncoder.Dataset.CIFARDataset import CIFARDataset
 
 from FunctionEncoder.Callbacks.BaseCallback import BaseCallback
 from FunctionEncoder.Callbacks.MSECallback import MSECallback
@@ -24,6 +25,7 @@ __all__ = [
     "GaussianDataset",
     "EuclideanDataset",
     "CategoricalDataset",
+    "CIFARDataset",
 
     "BaseCallback",
     "MSECallback",
